package canalrun.b4a.amznwrapper;

import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.ActivityObject;
import anywheresoftware.b4a.BA.DontInheritEvents;
import anywheresoftware.b4a.BA.Events;
import anywheresoftware.b4a.BA.Hide;
import anywheresoftware.b4a.BA.Permissions;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.BA.DependsOn;

import com.amazon.device.ads.*;

/*
 The AdMob library allows you to add ads served by AdMob to your application.
 See the AdMob Tutorial:
   http://www.basic4ppc.com/forum/basic4android-getting-started-tutorials/7300-admob-tutorial-add-ads-your-application.html.
 This library requires some additional configuration as described in the tutorial.
 This view must be set to a size of 320dip x 50dip. Otherwise it will not display.
 */
 
@Version(2.0f)
@Permissions(values={"android.permission.INTERNET", "android.permission.ACCESS_NETWORK_STATE",
  "android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION",
  "android.permission.ACCESS_WIFI_STATE"})
@ShortName("AmznAd2")
@DependsOn(values={"amazon-ads"})
@Events(values={"ReceiveAd", "FailedToReceiveAd (ErrorCode As String)", "AdExpanded", "AdCollapsed"})
@DontInheritEvents
@ActivityObject

public class AMZNWrapper extends ViewWrapper<AdLayout> {
  private static final String LOG_TAG = "AMZNWrapper"; // Tag used to prefix all log messages
  private BA locBA;
  private boolean bTest;

  /**
  Initializes the AdLayout.
    EventName - Name of Subs that will handle the events.
    PublisherId - The publisher id you received from Amazon.
    AdSz - Ad size string (300x50, 320x50, 300x250, 600x90, 728x90, 1024x50)
    TstMde - Test mode for ads.
  */
	 
  public void Initialize(final BA ba, String EventName, String PublisherId, String AdSz, boolean TstMde) {
    String s;
	  
	locBA = ba;
	bTest = TstMde;
	  
    if (AdSz.equals("300x50")) {
      setObject(new AdLayout(ba.activity, AdSize.SIZE_300x50));
      s = new String("300x50");
    }
    else if (AdSz.equals("320x50")) {
      setObject(new AdLayout(ba.activity, AdSize.SIZE_320x50));
      s = new String("320x50");
    }
    else if (AdSz.equals("300x250")) {
      setObject(new AdLayout(ba.activity, AdSize.SIZE_300x250));
      s = new String("300x250");
    }
    else if (AdSz.equals("600x90")) {
      setObject(new AdLayout(ba.activity, AdSize.SIZE_600x90));
      s = new String("600x90");
    }
    else if (AdSz.equals("728x90")) {
      setObject(new AdLayout(ba.activity, AdSize.SIZE_728x90));
      s = new String("728x90");
    }
    else {
      setObject(new AdLayout(ba.activity, AdSize.SIZE_1024x50));
      s = new String("1024x50");
    }
    
    super.Initialize(ba, EventName);
    
    myLog("Add Size: " + s);
    
    // For debugging purposes enable logging, but disable for production builds
    AdRegistration.enableLogging(TstMde);

    // For debugging purposes flag all ad requests as tests, but set to false for production builds
    AdRegistration.enableTesting(TstMde);

    try {
      AdRegistration.setAppKey(PublisherId);
    } catch (Exception e) {
    	myLog("AdReg Exception: " + e.toString());
      return;
    }
                
    final String eventName = EventName.toLowerCase(BA.cul);

    /**
     * This class is for an event listener that tracks ad lifecycle events.
     * It extends DefaultAdListener, so you can override only the methods that you need.
     */
    class SampleAdListener extends DefaultAdListener
    {
        /**
         * This event is called once an ad loads successfully.
         */
        @Override
        public void onAdLoaded(final Ad ad, final AdProperties adProperties) {
            ba.raiseEvent(getObject(), eventName + "_receivead");
            myLog(adProperties.getAdType().toString() + " Ad loaded successfully.");
        }
        
        /**
         * This event is called if an ad fails to load.
         */
        @Override
        public void onAdFailedToLoad(final Ad ad, final AdError e) {
            ba.raiseEvent(getObject(), eventName + "_failedtoreceivead", e.getMessage());
            myLog("Ad did not load. Code: " + e.getCode() + ", Message: " + e.getMessage());
        }
    
        /**
         * This event is called after a rich media ad expands.
         */
        
        @Override
        public void onAdExpanded(final Ad ad) {
            ba.raiseEvent(getObject(), eventName + "_adexpanded");
            myLog("Ad expanded.");
            // You may want to pause your activity here.
        }
        
        /**
         * This event is called after a rich media ad has collapsed from an expanded state.
         */
        @Override
        public void onAdCollapsed(final Ad ad) {
            ba.raiseEvent(getObject(), eventName + "_adcollapsed");
            myLog("Ad collapsed.");
            // Resume your activity here, if it was paused in onAdExpanded.
        }
    }

    getObject().setListener(new SampleAdListener());
  }
  
  // Write to B4A logs
  private void myLog(String msg) {
    if (bTest == true) {
 	  locBA.Log("AMZNAds - " + msg);
    }
  }

  // Load a new ad.
  public void LoadAd() { 
    // Load the ad with the appropriate ad targeting options.
    AdTargetingOptions adOptions = new AdTargetingOptions();
    getObject().loadAd(adOptions);
  }
}
